.. etler documentation master file, created by
   sphinx-quickstart on Sat Apr 20 18:10:55 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to etler's documentation!
=================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   etler


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
